@@ -75,7 +75,7 @@ class BaseHandler(tornado.web.RequestHandler):
         if not (self.args.t and self.args.n and self.args.s):
             raise tornado.web.HTTPError(403)
 
-        if time.time() - int(self.args.t, 16) >= 300:
+        if time.time() - int(self.args.t, 16) >= 600:
             raise tornado.web.HTTPError(403)
 
         if self.args.s != hashlib.md5(f'digua_{self.args.t}_{self.args.n}'.encode()).hexdigest():
@@ -85,7 +85,6 @@ class BaseHandler(tornado.web.RequestHandler):
         key = f'{self.prefix}_{self.args.s}'
         value = hashlib.md5(f'{self.ua}_{self.ip}_{self.args.s}'.encode()).hexdigest()
         check = await self.rd.get(key)
-        self.logger.info(f'check: {check}, value: {value}, {self.args}')
         if check is None:
             await self.rd.setex(key, 3600, value)
         elif check != value:
@@ -97,6 +96,8 @@ class BaseHandler(tornado.web.RequestHandler):
         if token and hasattr(self.app, 'db') and isinstance(self.app.db, (Mongo, Motor)):
             user = await awaitable(self.app.db.users.find_one({'token': token}))
             if user:
+                if self.args.token and not self.get_cookie('token'):
+                    self.set_cookie('token', self.args.token)
                 return user
         return Dict()
 
