@@ -58,14 +58,13 @@ class Config(Dict):
         cfg = Dict()
         if isinstance(config, dict):
             cfg.update(Dict(config))
-        elif config.endswith('.ini'):
-            cfg.update(Dict(Config._load_ini(config)))
-        elif config.endswith('.json'):
-            cfg.update(Dict(json.load(open(config))))
-        elif config.endswith('.yaml') or config.endswith('.yml'):
-            cfg.update(Dict(yaml.load(open(config), Loader=yaml.FullLoader)))
-        else:
-            raise TypeError(f'{config} must be dict, ini, json or yaml')
+        elif Path(config).exists():
+            if config.endswith('.ini'):
+                cfg.update(Dict(Config._load_ini(config)))
+            elif config.endswith('.json'):
+                cfg.update(Dict(json.load(open(config))))
+            elif config.endswith('.yaml') or config.endswith('.yml'):
+                cfg.update(Dict(yaml.load(open(config), Loader=yaml.FullLoader)))
 
         if cfg.extends:
             base = Dict()
