@@ -205,6 +205,7 @@ class Pycurl(BaseRequest):
             self.c.setopt(pycurl.PROGRESSFUNCTION, lambda a, b, c, d: pbar.update(int(b), int(a)))
             self.c.perform()
             pbar.close()
+            return self.c.getinfo(pycurl.HTTP_CODE) == 206
 
     def _request(self, url, **kwargs):
         url, kwargs = self._prepare(url, kwargs)
@@ -245,7 +246,7 @@ class Pycurl(BaseRequest):
         return resp
 
 
-class TornadoClient(Pycurl, AsyncRequest):
+class TornadoClient(AsyncRequest, Pycurl):
 
     def __init__(self, max_clients=100, **kwargs):
         ''' This cannot handle 301/302 redirection cookies
