@@ -320,7 +320,7 @@ class BaseRequest(metaclass=RequestMeta):
                 value[1].close()
 
     def _request(self, url, **kwargs):
-        pass
+        raise NotImplementedError
 
     def _retry(self, url, kwargs, retry):
         _kwargs = copy.deepcopy(kwargs)
@@ -342,6 +342,9 @@ class BaseRequest(metaclass=RequestMeta):
         else:
             return self._retry(url, kwargs, retry)
 
+    def _download(self, url, kwargs, fp, lock, start, end):
+        raise NotImplementedError
+
     def download(self, url, filename=None, shards=1, **kwargs):
         filename = Path(filename or Path(url).name)
         if shards > 1:
@@ -349,23 +352,28 @@ class BaseRequest(metaclass=RequestMeta):
             kwargs['headers']['Range'] = 'bytes=0-0'
             resp = self.request(url, **kwargs)
             filesize = int(resp.headers['Content-Range'].split('/')[-1])
-            lock = threading.Lock()
+            block = int(math.ceil(filesize / shards))
+            chunks = [(i * block, min(filesize, (i + 1) * block) - 1) for i in range(shards)]
+            args = list(zip(*chunks))
             filename.parent.mkdir(parents=True, exist_ok=True)
             with open(filename, 'wb') as fp:
                 fp.truncate(filesize)
             fp = open(filename, 'rb+')
-            block = int(math.ceil(filesize / shards))
-            chunks = [(i * block, min(filesize, (i + 1) * block) - 1) for i in range(shards)]
-            args = list(zip(*chunks))
+            lock = threading.Lock()
             func = partial(self._download, url, kwargs, fp, lock)
             with ThreadPoolExecutor(shards) as executor:
-                executor.map(func, *args)
+                results = executor.map(func, *args)
             fp.close()
+            ret = all(results)
+            if not ret:
+                filename.unlink()
+            return ret
         else:
             resp = self.request(url, **kwargs)
             if resp.code == 200:
                 filename.parent.mkdir(parents=True, exist_ok=True)
                 filename.write_bytes(resp.body)
+            return resp.code == 200
 
     def get(self, url, **kwargs):
         return self.request(url, method='get', **kwargs)
@@ -431,6 +439,16 @@ class AsyncRequest(BaseRequest):
                 await asyncio.sleep(self.sleep)
                 return await self._retry(url, _kwargs, retry - 1)
 
+    async def _download(self, url, kwargs, fp, lock, start, end):
+        kwargs = copy.deepcopy(kwargs)
+        kwargs['headers']['Range'] = f'bytes={start}-{end}'
+        resp = await self._request(url, **kwargs)
+        if resp.code == 206:
+            async with lock:
+                fp.seek(start)
+                fp.write(resp.body)
+        return resp.code == 206
+
     async def download(self, url, filename=None, shards=1, **kwargs):
         filename = Path(filename or Path(url).name)
         filename.parent.mkdir(parents=True, exist_ok=True)
@@ -440,22 +458,25 @@ class AsyncRequest(BaseRequest):
             resp = await self.request(url, **kwargs)
             filesize = int(resp.headers['Content-Range'].split('/')[-1])
             block = int(math.ceil(filesize / shards))
-            futures = []
-            for i in range(shards):
-                start = block * i
-                end = min(block * (i + 1), filesize) - 1
-                _kwargs = copy.deepcopy(kwargs)
-                _kwargs['headers']['Range'] = f'bytes={start}-{end}'
-                futures.append(self.request(url, **_kwargs))
-            resps = await asyncio.gather(*futures)
+            chunks = [(i * block, min(filesize, (i + 1) * block) - 1) for i in range(shards)]
+            filename.parent.mkdir(parents=True, exist_ok=True)
             with open(filename, 'wb') as fp:
-                for resp in resps:
-                    if resp.code == 206:
-                        fp.write(resp.body)
+                fp.truncate(filesize)
+            fp = open(filename, 'rb+')
+            lock = asyncio.Lock()
+            futures = [self._download(url, kwargs, fp, lock, start, end) for start, end in chunks]
+            results = await asyncio.gather(*futures)
+            fp.close()
+            ret = all(results)
+            if not ret:
+                filename.unlink()
+            return ret
         else:
             resp = await self.request(url, **kwargs)
             if resp.code == 200:
+                filename.parent.mkdir(parents=True, exist_ok=True)
                 filename.write_bytes(resp.body)
+            return resp.code == 200
 
 
 class Requests(BaseRequest):
@@ -517,15 +538,17 @@ class Requests(BaseRequest):
         kwargs['stream'] = True
         method = kwargs.pop('method', 'GET').upper()
         resp = self.session.request(method, url, **kwargs)
-        pbar = tqdm(total=end - start + 1, unit='B', unit_scale=True, desc=f'{start}')
-        for chunk in resp.iter_content(chunk_size=4096):
-            if chunk:
-                with lock:
-                    fp.seek(start)
-                    fp.write(chunk)
-                    start += len(chunk)
-                    pbar.update(incr=len(chunk))
-        pbar.close()
+        if resp.status_code == 206:
+            pbar = tqdm(total=end - start + 1, unit='B', unit_scale=True, desc=f'{start}')
+            for chunk in resp.iter_content(chunk_size=4096):
+                if chunk:
+                    with lock:
+                        fp.seek(start)
+                        fp.write(chunk)
+                        start += len(chunk)
+                        pbar.update(incr=len(chunk))
+            pbar.close()
+        return resp.status_code == 206
 
     def _request(self, url, **kwargs):
         url, kwargs = self._prepare(url, kwargs)
